@@ -1015,16 +1015,14 @@ eog_image_real_load (EogImage *img,
 		} else {
 			priv->status = EOG_IMAGE_STATUS_FAILED;
 		}
-	} else {
-		if (read_image_data) {
-			if (priv->image != NULL) {
-				g_object_unref (priv->image);
-			}
+	} else if (read_image_data) {
+		if (priv->image != NULL) {
+			g_object_unref (priv->image);
+		}
 
-			priv->image = gdk_pixbuf_loader_get_pixbuf (loader);
-
-			g_assert (priv->image != NULL);
+		priv->image = gdk_pixbuf_loader_get_pixbuf (loader);
 
+		if (G_LIKELY (priv->image != NULL)) {
 			g_object_ref (priv->image);
 
 			priv->width = gdk_pixbuf_get_width (priv->image);
@@ -1044,6 +1042,11 @@ eog_image_real_load (EogImage *img,
 					       0, 
 					       priv->width, 
 					       priv->height);
+		} else {
+			/* Some loaders don't report errors correctly.
+			 * Error will be set below. */
+			failed = TRUE;
+			priv->status = EOG_IMAGE_STATUS_FAILED;
 		}
 	}
 
@@ -1512,24 +1515,21 @@ eog_image_save_by_info (EogImage *img, EogImageSaveInfo *source, GError **error)
 }
 
 static gboolean
-eog_image_copy_file (EogImageSaveInfo *source, EogImageSaveInfo *target, GError **error)
+eog_image_copy_file (EogImage *image, EogImageSaveInfo *source, EogImageSaveInfo *target, GError **error)
 {
-	char *target_file_path;
 	gboolean result;
 	GError *ioerror;
 
 	g_return_val_if_fail (EOG_IS_IMAGE_SAVE_INFO (source), FALSE);
 	g_return_val_if_fail (EOG_IS_IMAGE_SAVE_INFO (target), FALSE);
 	
-	target_file_path = g_file_get_path (target->file);
-	
 	result = g_file_copy (source->file,
 			      target->file,
 			      (target->overwrite ? G_FILE_COPY_OVERWRITE : 0) |
 			      G_FILE_COPY_ALL_METADATA,
 			      NULL, 
-			      NULL,  /* no progress callback */
-			      NULL,
+			      EOG_IS_IMAGE (image) ? transfer_progress_cb :NULL,
+			      image,
 			      &ioerror);
 	
 	if (result == FALSE) {
@@ -1588,7 +1588,7 @@ eog_image_save_as_by_info (EogImage *img, EogImageSaveInfo *source, EogImageSave
 	
 	/* determine kind of saving */
 	if (g_ascii_strcasecmp (source->format, target->format) == 0 && !source->modified) {
-		success = eog_image_copy_file (source, target, error);
+		success = eog_image_copy_file (img, source, target, error);
 		direct_copy = success;
 	}
 
