@@ -2,14 +2,13 @@
 #define _EOG_PIXBUF_UTIL_H_
 
 #include <gdk-pixbuf/gdk-pixbuf.h>
-#include <libgnomevfs/gnome-vfs-uri.h>
+#include <gio/gio.h>
 
 GSList*          eog_pixbuf_get_savable_formats (void);
 
 GdkPixbufFormat* eog_pixbuf_get_format_by_suffix (const char *suffix);
 
-GdkPixbufFormat* eog_pixbuf_get_format_by_uri (const char *txt_uri);
-GdkPixbufFormat* eog_pixbuf_get_format_by_vfs_uri (const GnomeVFSURI *uri);
+GdkPixbufFormat* eog_pixbuf_get_format (GFile *file);
 
 char*            eog_pixbuf_get_common_suffix (GdkPixbufFormat *format);
 
